Welcome to the Community
========================

ml-stars library is an open source compendium of time series data transforms
that are used by machine learning practitioners.

It is a community driven effort, so it relies on the community. For this reason, we designed it
thoughtfully so much of the contributions here can have shelf life greater than any of the
machine learning libraries it integrates, as it represents the combined knowledge of all the
contributors and allows many different systems to be built using the annotations themselves.

So, are you ready to join the community? If so, please feel welcome and keep reading!

Types of contributions
----------------------

There are several ways to contribute to a project like **ml-stars**, and they do not always
involve coding.

If you want to contribute but do not know where to start, consider one of the following options:

Reporting Issues
~~~~~~~~~~~~~~~~

If there is something that you would like to see changed in the project, or that you just want
to ask, please create an issue at https://github.com/sintel-dev/ml-stars/issues

If you do so, please:

* Explain in detail what you are requesting.
* Keep the scope as narrow as possible, to make it easier to implement or respond.
* Remember that this is a volunteer-driven project and that the maintainers will attend every
  request as soon as possible, but that in some cases this might take some time.

Below there are some examples of the types of issues that you might want to create.

Request new primitives
**********************

Sometimes you will feel that a necessary primitive is missing and should be added.

In this case, please create an issue indicating the name of the primitive and a link to
its documentation.

If the primitive documentation is unclear or not precise enough to know what needs to be
done only by reading it, please add as many details as necessary in the issue description.

Request new features
********************

If there is any other feature that you would like to see implemented, such as adding new
functionalities to the existing custom primitives, or changing their behavior to cover
a broader range of cases, you can also create an issue.

If you do so, please indicate all the details about what you request as well as some use
cases of the new feature.

Report Bugs
***********

If you find something that fails, please report it including:

* Your operating system name and version.
* Any details about your local setup that might be helpful in troubleshooting.
* Detailed steps to reproduce the bug.

Ask for Documentation
*********************

If there is something that is not documented well enough, do not hesitate to point at that
in a new issue and request the necessary changes.

Write Documentation
~~~~~~~~~~~~~~~~~~~

ml-stars could always use more documentation, whether as part of the official MLPrimitives
docs, in docstrings, or even on the web in blog posts, articles, and such, so feel free to
contribute any changes that you deem necessary, from fixing a simple typo, to writing whole
new pages of documentation.

Contribute code
~~~~~~~~~~~~~~~

Obviously, the main element in the ml-stars library is the code.

If you are willing to contribute to it, please head for the next sections for detailed guidelines
about how to do so.

.. toctree::
    :maxdepth: 2

    contributing
    custom
    annotations
    adapters
